@@ -1,5 +1,9 @@
-DATABASE_ENGINE = "sqlite3"
-DATABASE_NAME = "testproject/test.db3"
+DATABASES = {
+    'default': {
+        'ENGINE': 'django.db.backends.sqlite3',
+        'NAME': 'testproject/test.db3',
+    }
+}
 INSTALLED_APPS = ["django_countries",
                   "django.contrib.auth",
                   "django.contrib.contenttypes",
